From 2695949a2ce2b9bf85878ea8cc9dc3bd55ed58fd Mon Sep 17 00:00:00 2001
From: Pankaj Yadav <pk@videolan.org>
Date: Tue, 11 Jan 2011 15:34:40 +0530
Subject: [PATCH] Symbian Specific Initialization routine

---
 src/Makefile.am        |    1 +
 src/symbian/specific.c |   91 ++++++++++++++++++++++++++++++++++++++++++++++++
 2 files changed, 92 insertions(+), 0 deletions(-)
 create mode 100644 src/symbian/specific.c

diff --git a/src/Makefile.am b/src/Makefile.am
index 7e5ba02..2881359 100755
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -303,6 +303,7 @@ SOURCES_libvlc_win32 = \
 SOURCES_libvlc_symbian = \
 	symbian/path.cpp \
         symbian/dirs.c \
+        symbian/specific.c \
 	$(NULL)
 
 SOURCES_libvlc_other = \
diff --git a/src/symbian/specific.c b/src/symbian/specific.c
new file mode 100644
index 0000000..2040552
--- /dev/null
+++ b/src/symbian/specific.c
@@ -0,0 +1,91 @@
+/*****************************************************************************
+ * symbian.c: OS-specific initialization
+ *****************************************************************************
+ * Copyright © 2010 Pankaj Yadav
+ * Author: Pankaj Yadav
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; either version 2.1 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
+ *****************************************************************************/
+#include "path.h"
+
+#ifdef HAVE_CONFIG_H
+# include "config.h"
+#endif
+
+#include <vlc_common.h>
+#include "../src/libvlc.h"
+#include <pthread.h>
+
+void * ThreadController ( void * );
+static vlc_thread_t threadid;
+static int quit = 0;
+static int ret;
+
+static void set_libvlc_path (void)
+{
+    char drive[11]="C:\\sys\\bin";
+    const char * letter;
+
+    letter=GetConstPrivatePath();
+
+    drive[0]=*letter;
+    free(letter);
+    psz_vlcpath = strdup(drive);
+}
+
+static void unset_libvlc_path (void)
+{
+    free (psz_vlcpath);
+}
+
+static struct
+{
+    vlc_mutex_t lock;
+    unsigned refs;
+} once = { VLC_STATIC_MUTEX, 0 };
+
+void system_Init (libvlc_int_t *libvlc, int *argc, const char *argv[])
+{
+    ret = pthread_create( &threadid, NULL, ThreadController, &quit );
+
+    vlc_mutex_lock ( &once.lock );
+    if (once.refs++ == 0)
+        set_libvlc_path ();
+    vlc_mutex_unlock ( &once.lock );
+
+    VLC_UNUSED(libvlc)
+    VLC_UNUSED(argc)
+    VLC_UNUSED(argv)
+}
+
+void system_Configure (libvlc_int_t *libvlc,
+                       int argc, const char *const argv[])
+{
+    VLC_UNUSED(libvlc)
+    VLC_UNUSED(argc)
+    VLC_UNUSED(argv)
+}
+
+void system_End (libvlc_int_t *libvlc)
+{
+    quit=1;
+
+    vlc_mutex_lock (&once.lock);
+    if (--once.refs == 0)
+        unset_libvlc_path ();
+    vlc_mutex_unlock (&once.lock);
+
+    VLC_UNUSED(libvlc)
+}
+
-- 
1.7.1

